@@ -33,19 +33,26 @@ __all__ = (
     "AnalyzedResourceTypeDef",
     "AnalyzerSummaryTypeDef",
     "ArchiveRuleSummaryTypeDef",
+    "CloudTrailPropertiesTypeDef",
     "ConfigurationTypeDef",
     "CriterionTypeDef",
     "FindingSourceDetailTypeDef",
     "FindingSourceTypeDef",
     "FindingSummaryTypeDef",
     "FindingTypeDef",
+    "GeneratedPolicyPropertiesTypeDef",
+    "GeneratedPolicyResultTypeDef",
+    "GeneratedPolicyTypeDef",
     "IamRoleConfigurationTypeDef",
+    "JobDetailsTypeDef",
+    "JobErrorTypeDef",
     "KmsGrantConfigurationTypeDef",
     "KmsGrantConstraintsTypeDef",
     "KmsKeyConfigurationTypeDef",
     "LocationTypeDef",
     "NetworkOriginConfigurationTypeDef",
     "PathElementTypeDef",
+    "PolicyGenerationTypeDef",
     "PositionTypeDef",
     "S3AccessPointConfigurationTypeDef",
     "S3BucketAclGrantConfigurationTypeDef",
@@ -56,8 +63,11 @@ __all__ = (
     "SqsQueueConfigurationTypeDef",
     "StatusReasonTypeDef",
     "SubstringTypeDef",
+    "TrailPropertiesTypeDef",
+    "TrailTypeDef",
     "ValidatePolicyFindingTypeDef",
     "VpcConfigurationTypeDef",
+    "CloudTrailDetailsTypeDef",
     "CreateAccessPreviewResponseTypeDef",
     "CreateAnalyzerResponseTypeDef",
     "GetAccessPreviewResponseTypeDef",
@@ -65,6 +75,7 @@ __all__ = (
     "GetAnalyzerResponseTypeDef",
     "GetArchiveRuleResponseTypeDef",
     "GetFindingResponseTypeDef",
+    "GetGeneratedPolicyResponseTypeDef",
     "InlineArchiveRuleTypeDef",
     "ListAccessPreviewFindingsResponseTypeDef",
     "ListAccessPreviewsResponseTypeDef",
@@ -72,9 +83,12 @@ __all__ = (
     "ListAnalyzersResponseTypeDef",
     "ListArchiveRulesResponseTypeDef",
     "ListFindingsResponseTypeDef",
+    "ListPolicyGenerationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "PolicyGenerationDetailsTypeDef",
     "SortCriteriaTypeDef",
+    "StartPolicyGenerationResponseTypeDef",
     "ValidatePolicyResponseTypeDef",
 )
 
@@ -258,6 +272,11 @@ ArchiveRuleSummaryTypeDef = TypedDict(
     },
 )
 
+CloudTrailPropertiesTypeDef = TypedDict(
+    "CloudTrailPropertiesTypeDef",
+    {"endTime": datetime, "startTime": datetime, "trailProperties": List["TrailPropertiesTypeDef"]},
+)
+
 ConfigurationTypeDef = TypedDict(
     "ConfigurationTypeDef",
     {
@@ -370,10 +389,76 @@ class FindingTypeDef(_RequiredFindingTypeDef, _OptionalFindingTypeDef):
     pass
 
 
+_RequiredGeneratedPolicyPropertiesTypeDef = TypedDict(
+    "_RequiredGeneratedPolicyPropertiesTypeDef", {"principalArn": str}
+)
+_OptionalGeneratedPolicyPropertiesTypeDef = TypedDict(
+    "_OptionalGeneratedPolicyPropertiesTypeDef",
+    {"cloudTrailProperties": "CloudTrailPropertiesTypeDef", "isComplete": bool},
+    total=False,
+)
+
+
+class GeneratedPolicyPropertiesTypeDef(
+    _RequiredGeneratedPolicyPropertiesTypeDef, _OptionalGeneratedPolicyPropertiesTypeDef
+):
+    pass
+
+
+_RequiredGeneratedPolicyResultTypeDef = TypedDict(
+    "_RequiredGeneratedPolicyResultTypeDef", {"properties": "GeneratedPolicyPropertiesTypeDef"}
+)
+_OptionalGeneratedPolicyResultTypeDef = TypedDict(
+    "_OptionalGeneratedPolicyResultTypeDef",
+    {"generatedPolicies": List["GeneratedPolicyTypeDef"]},
+    total=False,
+)
+
+
+class GeneratedPolicyResultTypeDef(
+    _RequiredGeneratedPolicyResultTypeDef, _OptionalGeneratedPolicyResultTypeDef
+):
+    pass
+
+
+GeneratedPolicyTypeDef = TypedDict("GeneratedPolicyTypeDef", {"policy": str})
+
 IamRoleConfigurationTypeDef = TypedDict(
     "IamRoleConfigurationTypeDef", {"trustPolicy": str}, total=False
 )
 
+_RequiredJobDetailsTypeDef = TypedDict(
+    "_RequiredJobDetailsTypeDef",
+    {
+        "jobId": str,
+        "startedOn": datetime,
+        "status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELED"],
+    },
+)
+_OptionalJobDetailsTypeDef = TypedDict(
+    "_OptionalJobDetailsTypeDef",
+    {"completedOn": datetime, "jobError": "JobErrorTypeDef"},
+    total=False,
+)
+
+
+class JobDetailsTypeDef(_RequiredJobDetailsTypeDef, _OptionalJobDetailsTypeDef):
+    pass
+
+
+JobErrorTypeDef = TypedDict(
+    "JobErrorTypeDef",
+    {
+        "code": Literal[
+            "AUTHORIZATION_ERROR",
+            "RESOURCE_NOT_FOUND_ERROR",
+            "SERVICE_QUOTA_EXCEEDED_ERROR",
+            "SERVICE_ERROR",
+        ],
+        "message": str,
+    },
+)
+
 _RequiredKmsGrantConfigurationTypeDef = TypedDict(
     "_RequiredKmsGrantConfigurationTypeDef",
     {
@@ -440,6 +525,24 @@ PathElementTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPolicyGenerationTypeDef = TypedDict(
+    "_RequiredPolicyGenerationTypeDef",
+    {
+        "jobId": str,
+        "principalArn": str,
+        "startedOn": datetime,
+        "status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELED"],
+    },
+)
+_OptionalPolicyGenerationTypeDef = TypedDict(
+    "_OptionalPolicyGenerationTypeDef", {"completedOn": datetime}, total=False
+)
+
+
+class PolicyGenerationTypeDef(_RequiredPolicyGenerationTypeDef, _OptionalPolicyGenerationTypeDef):
+    pass
+
+
 PositionTypeDef = TypedDict("PositionTypeDef", {"column": int, "line": int, "offset": int})
 
 S3AccessPointConfigurationTypeDef = TypedDict(
@@ -500,6 +603,28 @@ StatusReasonTypeDef = TypedDict(
 
 SubstringTypeDef = TypedDict("SubstringTypeDef", {"length": int, "start": int})
 
+_RequiredTrailPropertiesTypeDef = TypedDict(
+    "_RequiredTrailPropertiesTypeDef", {"cloudTrailArn": str}
+)
+_OptionalTrailPropertiesTypeDef = TypedDict(
+    "_OptionalTrailPropertiesTypeDef", {"allRegions": bool, "regions": List[str]}, total=False
+)
+
+
+class TrailPropertiesTypeDef(_RequiredTrailPropertiesTypeDef, _OptionalTrailPropertiesTypeDef):
+    pass
+
+
+_RequiredTrailTypeDef = TypedDict("_RequiredTrailTypeDef", {"cloudTrailArn": str})
+_OptionalTrailTypeDef = TypedDict(
+    "_OptionalTrailTypeDef", {"allRegions": bool, "regions": List[str]}, total=False
+)
+
+
+class TrailTypeDef(_RequiredTrailTypeDef, _OptionalTrailTypeDef):
+    pass
+
+
 ValidatePolicyFindingTypeDef = TypedDict(
     "ValidatePolicyFindingTypeDef",
     {
@@ -513,6 +638,21 @@ ValidatePolicyFindingTypeDef = TypedDict(
 
 VpcConfigurationTypeDef = TypedDict("VpcConfigurationTypeDef", {"vpcId": str})
 
+_RequiredCloudTrailDetailsTypeDef = TypedDict(
+    "_RequiredCloudTrailDetailsTypeDef",
+    {"accessRole": str, "startTime": datetime, "trails": List["TrailTypeDef"]},
+)
+_OptionalCloudTrailDetailsTypeDef = TypedDict(
+    "_OptionalCloudTrailDetailsTypeDef", {"endTime": datetime}, total=False
+)
+
+
+class CloudTrailDetailsTypeDef(
+    _RequiredCloudTrailDetailsTypeDef, _OptionalCloudTrailDetailsTypeDef
+):
+    pass
+
+
 CreateAccessPreviewResponseTypeDef = TypedDict("CreateAccessPreviewResponseTypeDef", {"id": str})
 
 CreateAnalyzerResponseTypeDef = TypedDict(
@@ -539,6 +679,11 @@ GetFindingResponseTypeDef = TypedDict(
     "GetFindingResponseTypeDef", {"finding": "FindingTypeDef"}, total=False
 )
 
+GetGeneratedPolicyResponseTypeDef = TypedDict(
+    "GetGeneratedPolicyResponseTypeDef",
+    {"generatedPolicyResult": "GeneratedPolicyResultTypeDef", "jobDetails": "JobDetailsTypeDef"},
+)
+
 InlineArchiveRuleTypeDef = TypedDict(
     "InlineArchiveRuleTypeDef", {"filter": Dict[str, "CriterionTypeDef"], "ruleName": str}
 )
@@ -631,6 +776,21 @@ class ListFindingsResponseTypeDef(
     pass
 
 
+_RequiredListPolicyGenerationsResponseTypeDef = TypedDict(
+    "_RequiredListPolicyGenerationsResponseTypeDef",
+    {"policyGenerations": List["PolicyGenerationTypeDef"]},
+)
+_OptionalListPolicyGenerationsResponseTypeDef = TypedDict(
+    "_OptionalListPolicyGenerationsResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListPolicyGenerationsResponseTypeDef(
+    _RequiredListPolicyGenerationsResponseTypeDef, _OptionalListPolicyGenerationsResponseTypeDef
+):
+    pass
+
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
 )
@@ -639,10 +799,16 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
+PolicyGenerationDetailsTypeDef = TypedDict("PolicyGenerationDetailsTypeDef", {"principalArn": str})
+
 SortCriteriaTypeDef = TypedDict(
     "SortCriteriaTypeDef", {"attributeName": str, "orderBy": Literal["ASC", "DESC"]}, total=False
 )
 
+StartPolicyGenerationResponseTypeDef = TypedDict(
+    "StartPolicyGenerationResponseTypeDef", {"jobId": str}
+)
+
 _RequiredValidatePolicyResponseTypeDef = TypedDict(
     "_RequiredValidatePolicyResponseTypeDef", {"findings": List["ValidatePolicyFindingTypeDef"]}
 )
